/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataplatformClusterConfig extends cdktf.TerraformMetaArguments {
    /**
    * The UUID of the virtual data center (VDC) in which the cluster is provisioned
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/ionos-cloud/ionoscloud/6.4.19/docs/resources/dataplatform_cluster#datacenter_id DataplatformCluster#datacenter_id}
    */
    readonly datacenterId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/ionos-cloud/ionoscloud/6.4.19/docs/resources/dataplatform_cluster#id DataplatformCluster#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of your cluster. Must be 63 characters or less and must be empty or begin and end with an alphanumeric character ([a-z0-9A-Z]). It can contain dashes (-), underscores (_), dots (.), and alphanumerics in-between.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/ionos-cloud/ionoscloud/6.4.19/docs/resources/dataplatform_cluster#name DataplatformCluster#name}
    */
    readonly name: string;
    /**
    * The version of the Data Platform.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/ionos-cloud/ionoscloud/6.4.19/docs/resources/dataplatform_cluster#version DataplatformCluster#version}
    */
    readonly version?: string;
    /**
    * lans block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/ionos-cloud/ionoscloud/6.4.19/docs/resources/dataplatform_cluster#lans DataplatformCluster#lans}
    */
    readonly lans?: DataplatformClusterLans[] | cdktf.IResolvable;
    /**
    * maintenance_window block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/ionos-cloud/ionoscloud/6.4.19/docs/resources/dataplatform_cluster#maintenance_window DataplatformCluster#maintenance_window}
    */
    readonly maintenanceWindow?: DataplatformClusterMaintenanceWindow[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/ionos-cloud/ionoscloud/6.4.19/docs/resources/dataplatform_cluster#timeouts DataplatformCluster#timeouts}
    */
    readonly timeouts?: DataplatformClusterTimeouts;
}
export interface DataplatformClusterLansRoutes {
    /**
    * IPv4 or IPv6 gateway IP for the route
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/ionos-cloud/ionoscloud/6.4.19/docs/resources/dataplatform_cluster#gateway DataplatformCluster#gateway}
    */
    readonly gateway: string;
    /**
    * IPv4 or IPv6 CIDR to be routed via the interface
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/ionos-cloud/ionoscloud/6.4.19/docs/resources/dataplatform_cluster#network DataplatformCluster#network}
    */
    readonly network: string;
}
export declare function dataplatformClusterLansRoutesToTerraform(struct?: DataplatformClusterLansRoutes | cdktf.IResolvable): any;
export declare function dataplatformClusterLansRoutesToHclTerraform(struct?: DataplatformClusterLansRoutes | cdktf.IResolvable): any;
export declare class DataplatformClusterLansRoutesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplatformClusterLansRoutes | cdktf.IResolvable | undefined;
    set internalValue(value: DataplatformClusterLansRoutes | cdktf.IResolvable | undefined);
    private _gateway?;
    get gateway(): string;
    set gateway(value: string);
    get gatewayInput(): string | undefined;
    private _network?;
    get network(): string;
    set network(value: string);
    get networkInput(): string | undefined;
}
export declare class DataplatformClusterLansRoutesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataplatformClusterLansRoutes[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplatformClusterLansRoutesOutputReference;
}
export interface DataplatformClusterLans {
    /**
    * Indicates if the Kubernetes node pool LAN will reserve an IP using DHCP. The default value is 'true'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/ionos-cloud/ionoscloud/6.4.19/docs/resources/dataplatform_cluster#dhcp DataplatformCluster#dhcp}
    */
    readonly dhcp?: boolean | cdktf.IResolvable;
    /**
    * The LAN ID of an existing LAN at the related data center
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/ionos-cloud/ionoscloud/6.4.19/docs/resources/dataplatform_cluster#lan_id DataplatformCluster#lan_id}
    */
    readonly lanId: string;
    /**
    * routes block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/ionos-cloud/ionoscloud/6.4.19/docs/resources/dataplatform_cluster#routes DataplatformCluster#routes}
    */
    readonly routes?: DataplatformClusterLansRoutes[] | cdktf.IResolvable;
}
export declare function dataplatformClusterLansToTerraform(struct?: DataplatformClusterLans | cdktf.IResolvable): any;
export declare function dataplatformClusterLansToHclTerraform(struct?: DataplatformClusterLans | cdktf.IResolvable): any;
export declare class DataplatformClusterLansOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplatformClusterLans | cdktf.IResolvable | undefined;
    set internalValue(value: DataplatformClusterLans | cdktf.IResolvable | undefined);
    private _dhcp?;
    get dhcp(): boolean | cdktf.IResolvable;
    set dhcp(value: boolean | cdktf.IResolvable);
    resetDhcp(): void;
    get dhcpInput(): boolean | cdktf.IResolvable | undefined;
    private _lanId?;
    get lanId(): string;
    set lanId(value: string);
    get lanIdInput(): string | undefined;
    private _routes;
    get routes(): DataplatformClusterLansRoutesList;
    putRoutes(value: DataplatformClusterLansRoutes[] | cdktf.IResolvable): void;
    resetRoutes(): void;
    get routesInput(): cdktf.IResolvable | DataplatformClusterLansRoutes[] | undefined;
}
export declare class DataplatformClusterLansList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataplatformClusterLans[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplatformClusterLansOutputReference;
}
export interface DataplatformClusterMaintenanceWindow {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/ionos-cloud/ionoscloud/6.4.19/docs/resources/dataplatform_cluster#day_of_the_week DataplatformCluster#day_of_the_week}
    */
    readonly dayOfTheWeek: string;
    /**
    * Time at which the maintenance should start.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/ionos-cloud/ionoscloud/6.4.19/docs/resources/dataplatform_cluster#time DataplatformCluster#time}
    */
    readonly time: string;
}
export declare function dataplatformClusterMaintenanceWindowToTerraform(struct?: DataplatformClusterMaintenanceWindow | cdktf.IResolvable): any;
export declare function dataplatformClusterMaintenanceWindowToHclTerraform(struct?: DataplatformClusterMaintenanceWindow | cdktf.IResolvable): any;
export declare class DataplatformClusterMaintenanceWindowOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplatformClusterMaintenanceWindow | cdktf.IResolvable | undefined;
    set internalValue(value: DataplatformClusterMaintenanceWindow | cdktf.IResolvable | undefined);
    private _dayOfTheWeek?;
    get dayOfTheWeek(): string;
    set dayOfTheWeek(value: string);
    get dayOfTheWeekInput(): string | undefined;
    private _time?;
    get time(): string;
    set time(value: string);
    get timeInput(): string | undefined;
}
export declare class DataplatformClusterMaintenanceWindowList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataplatformClusterMaintenanceWindow[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplatformClusterMaintenanceWindowOutputReference;
}
export interface DataplatformClusterTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/ionos-cloud/ionoscloud/6.4.19/docs/resources/dataplatform_cluster#create DataplatformCluster#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/ionos-cloud/ionoscloud/6.4.19/docs/resources/dataplatform_cluster#default DataplatformCluster#default}
    */
    readonly default?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/ionos-cloud/ionoscloud/6.4.19/docs/resources/dataplatform_cluster#delete DataplatformCluster#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/ionos-cloud/ionoscloud/6.4.19/docs/resources/dataplatform_cluster#update DataplatformCluster#update}
    */
    readonly update?: string;
}
export declare function dataplatformClusterTimeoutsToTerraform(struct?: DataplatformClusterTimeouts | cdktf.IResolvable): any;
export declare function dataplatformClusterTimeoutsToHclTerraform(struct?: DataplatformClusterTimeouts | cdktf.IResolvable): any;
export declare class DataplatformClusterTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataplatformClusterTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: DataplatformClusterTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _default?;
    get default(): string;
    set default(value: string);
    resetDefault(): void;
    get defaultInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/ionos-cloud/ionoscloud/6.4.19/docs/resources/dataplatform_cluster ionoscloud_dataplatform_cluster}
*/
export declare class DataplatformCluster extends cdktf.TerraformResource {
    static readonly tfResourceType = "ionoscloud_dataplatform_cluster";
    /**
    * Generates CDKTF code for importing a DataplatformCluster resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataplatformCluster to import
    * @param importFromId The id of the existing DataplatformCluster that should be imported. Refer to the {@link https://registry.terraform.io/providers/ionos-cloud/ionoscloud/6.4.19/docs/resources/dataplatform_cluster#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataplatformCluster to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/ionos-cloud/ionoscloud/6.4.19/docs/resources/dataplatform_cluster ionoscloud_dataplatform_cluster} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataplatformClusterConfig
    */
    constructor(scope: Construct, id: string, config: DataplatformClusterConfig);
    private _datacenterId?;
    get datacenterId(): string;
    set datacenterId(value: string);
    get datacenterIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _version?;
    get version(): string;
    set version(value: string);
    resetVersion(): void;
    get versionInput(): string | undefined;
    private _lans;
    get lans(): DataplatformClusterLansList;
    putLans(value: DataplatformClusterLans[] | cdktf.IResolvable): void;
    resetLans(): void;
    get lansInput(): cdktf.IResolvable | DataplatformClusterLans[] | undefined;
    private _maintenanceWindow;
    get maintenanceWindow(): DataplatformClusterMaintenanceWindowList;
    putMaintenanceWindow(value: DataplatformClusterMaintenanceWindow[] | cdktf.IResolvable): void;
    resetMaintenanceWindow(): void;
    get maintenanceWindowInput(): cdktf.IResolvable | DataplatformClusterMaintenanceWindow[] | undefined;
    private _timeouts;
    get timeouts(): DataplatformClusterTimeoutsOutputReference;
    putTimeouts(value: DataplatformClusterTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | DataplatformClusterTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
